@@ -1,4 +1,4 @@
-from eloquentarduino.ml.data.loaders import load_folder, load_folder_streaming, rolling_window
+from eloquentarduino.ml.data.loaders import load_folder, load_folder_streaming, rolling_window, load_datasets_from_folder
 from eloquentarduino.ml.data.processing import describe_data
 from eloquentarduino.ml.data.preprocessing import PrincipalFFT
 from eloquentarduino.ml.data.Pipeline import Pipeline
